# - Try to find the Kdcraw library
# Once done this will define
#
#  KDCRAW_FOUND - system has libkdcraw
#  KDCRAW_INCLUDE_DIR - the libkdcraw include directory
#  KDCRAW_LIBRARIES - Link these to use libkdcraw
#  KDCRAW_DEFINITIONS - Compiler switches required for using libkdcraw
#

# Copyright (c) 2008, Gilles Caulier, <caulier.gilles@gmail.com>
#
# Redistribution and use is allowed according to the terms of the BSD license.
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.


if (KDCRAW_INCLUDE_DIR AND KDCRAW_LIBRARIES)

  message(STATUS "Found Kdcraw library in cache: ${KDCRAW_LIBRARIES}")

  # in cache already
  SET(KDCRAW_FOUND TRUE)

else (KDCRAW_INCLUDE_DIR AND KDCRAW_LIBRARIES)

  message(STATUS "Check Kdcraw library in local sub-folder...")

  # Check if library is not in local sub-folder
 
  FIND_FILE(KDCRAW_LOCAL_FOUND libkdcraw/kdcraw.h ${CMAKE_SOURCE_DIR}/libkdcraw ${CMAKE_SOURCE_DIR}/libs/libkdcraw NO_DEFAULT_PATH)

  if (KDCRAW_LOCAL_FOUND)

    # Was it found in libkdcraw/ or in libs/libkdcraw?
    FIND_FILE(KDCRAW_LOCAL_FOUND_IN_LIBS libkdcraw/kdcraw.h ${CMAKE_SOURCE_DIR}/libs/libkdcraw NO_DEFAULT_PATH)
    if (KDCRAW_LOCAL_FOUND_IN_LIBS)
      set(KDCRAW_INCLUDE_DIR ${CMAKE_SOURCE_DIR}/libs/libkdcraw)
    else (KDCRAW_LOCAL_FOUND_IN_LIBS)
      set(KDCRAW_INCLUDE_DIR ${CMAKE_SOURCE_DIR}/libkdcraw)
    endif (KDCRAW_LOCAL_FOUND_IN_LIBS)
    set(KDCRAW_DEFINITIONS "-I${KDCRAW_INCLUDE_DIR}")
    set(KDCRAW_LIBRARIES kdcraw)
    message(STATUS "Found Kdcraw library in local sub-folder: ${KDCRAW_INCLUDE_DIR}")
    set(KDCRAW_FOUND TRUE)
    MARK_AS_ADVANCED(KDCRAW_INCLUDE_DIR KDCRAW_LIBRARIES)

  else(KDCRAW_LOCAL_FOUND)

    if(NOT WIN32)
      message(STATUS "Check Kdcraw library using pkg-config...")

      # use pkg-config to get the directories and then use these values
      # in the FIND_PATH() and FIND_LIBRARY() calls
      include(FindPkgConfig)
      pkg_check_modules(PC_LIBKDCRAW libkdcraw-kde4>=0.2.0)
      set(KDCRAW_DEFINITIONS ${PC_LIBKDCRAW_CFLAGS_OTHER})
    endif(NOT WIN32)

    find_path(KDCRAW_INCLUDE_DIR NAMES libkdcraw/version.h
        HINTS
        ${PC_LIBKDCRAW_INCLUDEDIR}
        ${PC_LIBKDCRAW_INCLUDE_DIRS}
        )
    find_library(KDCRAW_LIBRARY NAMES kdcraw
        HINTS
        ${PC_LIBKDCRAW_LIBDIR}
        ${PC_LIBKDCRAW_LIBRARY_DIRS}
        )

    include(FindPackageHandleStandardArgs)
    find_package_handle_standard_args(Kdcraw DEFAULT_MSG KDCRAW_LIBRARY KDCRAW_INCLUDE_DIR)

    if(KDCRAW_FOUND)
       set(KDCRAW_LIBRARIES ${KDCRAW_LIBRARY})
    endif(KDCRAW_FOUND)
    
    MARK_AS_ADVANCED(KDCRAW_INCLUDE_DIR KDCRAW_LIBRARIES)

  endif(KDCRAW_LOCAL_FOUND)
  
endif (KDCRAW_INCLUDE_DIR AND KDCRAW_LIBRARIES)
