# - Try to find the Kipi library
# Once done this will define
#
#  KIPI_FOUND - system has libkipi
#  KIPI_INCLUDE_DIR - the libkipi include directory
#  KIPI_LIBRARIES - Link these to use libkipi
#  KIPI_DEFINITIONS - Compiler switches required for using libkipi
#

# Copyright (c) 2008, Gilles Caulier, <caulier.gilles@gmail.com>
#
# Redistribution and use is allowed according to the terms of the BSD license.
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.

if (KIPI_INCLUDE_DIR AND KIPI_LIBRARIES)

  message(STATUS "Found Kipi library in cache: ${KIPI_LIBRARIES}")

  # in cache already
  SET(KIPI_FOUND TRUE)

else (KIPI_INCLUDE_DIR AND KIPI_LIBRARIES)

  message(STATUS "Check Kipi library in local sub-folder...")

  # Check if library is not in local sub-folder

  find_file (KIPI_LOCAL_FOUND libkipi/version.h.cmake ${CMAKE_SOURCE_DIR}/libkipi ${CMAKE_SOURCE_DIR}/libs/libkipi NO_DEFAULT_PATH)

  if (KIPI_LOCAL_FOUND)

    find_file (KIPI_LOCAL_FOUND_IN_LIBS libkipi/version.h.cmake ${CMAKE_SOURCE_DIR}/libs/libkipi NO_DEFAULT_PATH)
    if (KIPI_LOCAL_FOUND_IN_LIBS)
      set(KIPI_INCLUDE_DIR ${CMAKE_SOURCE_DIR}/libs/libkipi)
    else (KIPI_LOCAL_FOUND_IN_LIBS)
      set(KIPI_INCLUDE_DIR ${CMAKE_SOURCE_DIR}/libkipi)
    endif (KIPI_LOCAL_FOUND_IN_LIBS)
    set(KIPI_DEFINITIONS -I${KIPI_INCLUDE_DIR})
    set(KIPI_LIBRARIES kipi)
    message(STATUS "Found Kipi library in local sub-folder: ${KIPI_INCLUDE_DIR}")
    set(KIPI_FOUND TRUE)
    mark_as_advanced(KIPI_INCLUDE_DIR KIPI_LIBRARIES)

  else(KIPI_LOCAL_FOUND)

    if(NOT WIN32)
      message(STATUS "Check Kipi library using pkg-config...")

      # use pkg-config to get the directories and then use these values
      # in the FIND_PATH() and FIND_LIBRARY() calls
      include(FindPkgConfig)
      pkg_check_modules(PC_LIBKIPI libkexiv2-kde4>=0.2.0)
      set(KIPI_DEFINITIONS ${PC_LIBKIPI_CFLAGS_OTHER})
    endif(NOT WIN32)

    find_path(KIPI_INCLUDE_DIR NAMES libkipi/version.h
        HINTS
        ${PC_LIBKIPI_INCLUDEDIR}
        ${PC_LIBKIPI_INCLUDE_DIRS}
        )
    find_library(KIPI_LIBRARY NAMES kipi
        HINTS
        ${PC_LIBKIPI_LIBDIR}
        ${PC_LIBKIPI_LIBRARY_DIRS}
        )

    include(FindPackageHandleStandardArgs)
    find_package_handle_standard_args(Kipi DEFAULT_MSG KIPI_LIBRARY KIPI_INCLUDE_DIR)

    if(KIPI_FOUND)
       set(KIPI_LIBRARIES ${KIPI_LIBRARY})
    endif(KIPI_FOUND)
    
    MARK_AS_ADVANCED(KIPI_INCLUDE_DIR KIPI_LIBRARIES)

  endif(KIPI_LOCAL_FOUND)
  
endif (KIPI_INCLUDE_DIR AND KIPI_LIBRARIES)
